#!/usr/bin/env python3

# This file is part of Remote Support Desktop
# https://gitlab.das-netzwerkteam.de/RemoteWebApp/rwa.support.sessionservice
# Copyright 2020, 2021 Jonathan Weth <dev@jonathanweth.de>
# Copyright 2020, 2021 Daniel Teichmann <daniel.teichmann@das-netzwerkteam.de>
# Copyright 2020 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
# SPDX-License-Identifier: GPL-2.0-or-later
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


import click
import dbus

try:
    bus = dbus.SessionBus()
    req = bus.get_object("org.ArcticaProject.RWASupportSessionService", "/RWASupportSessionService")
except dbus.exceptions.DBusException:
    click.echo("The D-Bus service isn't responding! Is it even started? Aborting ...")
    exit(1)


@click.group()
def cli():
    pass


@cli.command()
@click.argument("host", type=int)
def start(host: int):
    """Start a session on the RWA.Support.WebApp host with index HOST."""
    click.echo(f"Sending D-Bus request 'start': {host}")
    response = req.start(host)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("pid", type=int)
def stop(pid: int):
    """Stop the session with the pid PID."""
    click.echo(f"Sending D-Bus request 'stop' with PID {pid}")
    response = req.stop(pid)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("pid", type=int)
def status(pid: int):
    """Get the status of the session with the pid PID."""
    click.echo(f"Sending D-Bus request 'status' with PID {pid}")
    response = req.status(pid)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("pid", type=int)
def refresh_status(pid: int):
    """Refresh and get the status of the session with the pid PID."""
    click.echo(f"Sending D-Bus request 'refresh_status' with PID {pid}")
    response = req.refresh_status(pid)
    click.echo(f"Your response is: {response}")


if __name__ == "__main__":
    cli()
